@@ -20,30 +20,26 @@ package handler
 import (
 	"context"
 	"fmt"
-	"github.com/IrineSistiana/mosdns/v2/dispatcher/mlog"
+	"github.com/IrineSistiana/mosdns/v3/dispatcher/mlog"
 	"go.uber.org/zap"
 )
 
 var (
 	_ Executable = (*PluginWrapper)(nil)
 	_ Matcher    = (*PluginWrapper)(nil)
-	_ Service    = (*PluginWrapper)(nil)
 )
 
 // PluginWrapper wraps the original plugin to avoid extremely frequently
-// interface conversion. To access the original plugin, use PluginWrapper.GetPlugin()
-// Note: PluginWrapper not implements Executable.
-// It automatically converts Executable to ESExecutable.
+// interface conversion.
 type PluginWrapper struct {
-	p Plugin
+	Plugin
 	e Executable
 	m Matcher
-	s Service
 }
 
 func NewPluginWrapper(gp Plugin) *PluginWrapper {
 	w := new(PluginWrapper)
-	w.p = gp
+	w.Plugin = gp
 
 	if se, ok := gp.(Executable); ok {
 		w.e = se
@@ -51,23 +47,16 @@ func NewPluginWrapper(gp Plugin) *PluginWrapper {
 	if m, ok := gp.(Matcher); ok {
 		w.m = m
 	}
-	if s, ok := gp.(Service); ok {
-		w.s = s
-	}
 
 	return w
 }
 
-func (w *PluginWrapper) GetPlugin() Plugin {
-	return w.p
-}
-
 func (w *PluginWrapper) Match(ctx context.Context, qCtx *Context) (matched bool, err error) {
 	matched, err = w.match(ctx, qCtx)
 	if err != nil {
-		return false, NewPluginError(w.p.Tag(), err)
+		return false, NewPluginError(w.Tag(), err)
 	}
-	mlog.L().Debug("matching query context", qCtx.InfoField(), zap.String("tag", w.p.Tag()), zap.Bool("result", matched))
+	mlog.L().Debug("matching query context", qCtx.InfoField(), zap.String("tag", w.Tag()), zap.Bool("result", matched))
 	return matched, nil
 }
 
@@ -77,17 +66,17 @@ func (w *PluginWrapper) match(ctx context.Context, qCtx *Context) (matched bool,
 	}
 
 	if w.m == nil {
-		return false, fmt.Errorf("plugin tag: %s, type: %s is not a Matcher", w.p.Tag(), w.p.Type())
+		return false, fmt.Errorf("plugin tag: %s, type: %s is not a Matcher", w.Tag(), w.Type())
 	}
 
 	return w.m.Match(ctx, qCtx)
 }
 
 func (w *PluginWrapper) Exec(ctx context.Context, qCtx *Context, next ExecutableChainNode) error {
-	mlog.L().Debug("executing plugin", qCtx.InfoField(), zap.String("tag", w.p.Tag()))
+	mlog.L().Debug("executing plugin", qCtx.InfoField(), zap.String("tag", w.Tag()))
 	err := w.exec(ctx, qCtx, next)
 	if err != nil {
-		return NewPluginError(w.p.Tag(), err)
+		return NewPluginError(w.Tag(), err)
 	}
 	return nil
 }
@@ -98,31 +87,17 @@ func (w *PluginWrapper) exec(ctx context.Context, qCtx *Context, next Executable
 	}
 
 	if w.e == nil {
-		return fmt.Errorf("plugin tag: %s, type: %s is not an ESExecutable nor Executable", w.p.Tag(), w.p.Type())
+		return fmt.Errorf("plugin tag: %s, type: %s is not an ESExecutable nor Executable", w.Tag(), w.Type())
 	}
 
 	return w.e.Exec(ctx, qCtx, next)
 }
 
-func (w *PluginWrapper) Shutdown() error {
-	mlog.L().Debug("shutting down service", zap.String("tag", w.p.Tag()))
-
-	if w.s == nil {
-		return fmt.Errorf("plugin tag: %s, type: %s is not a Service", w.p.Tag(), w.p.Type())
-	}
-	err := w.s.Shutdown()
-	if err != nil {
-		return NewPluginError(w.p.Tag(), err)
-	}
-	return nil
-}
-
 type PluginInterfaceType uint8
 
 const (
-	PITESExecutable = iota
+	PITESExecutable PluginInterfaceType = iota
 	PITMatcher
-	PITService
 )
 
 func (w *PluginWrapper) Is(t PluginInterfaceType) bool {
@@ -131,8 +106,6 @@ func (w *PluginWrapper) Is(t PluginInterfaceType) bool {
 		return w.e != nil
 	case PITMatcher:
 		return w.m != nil
-	case PITService:
-		return w.s != nil
 	default:
 		panic(fmt.Sprintf("hander: invalid PluginInterfaceType: %d", t))
 	}
