@@ -22,16 +22,27 @@ import (
 	"github.com/miekg/dns"
 )
 
-func PackBuffer(m *dns.Msg) (wire, buf []byte, err error) {
+// PackBuffer packs the dns msg m to wire format.
+// Callers should release the buf after they have done with the wire []byte.
+func PackBuffer(m *dns.Msg) (wire []byte, buf *Buffer, err error) {
 	l := m.Len()
 	if l > dns.MaxMsgSize || l <= 0 {
 		return nil, nil, fmt.Errorf("msg length %d is invalid", l)
 	}
-	buf = allocator.Get(l + 4) // m.PackBuffer(buf) needs one more bit than its length. Wired. We give it a little more.
 
-	wire, err = m.PackBuffer(buf)
+	// dns.Msg.PackBuffer() needs one more bit than its msg length.
+	// It also needs a much larger buffer if the msg is compressed.
+	// It is tedious to force dns.Msg.PackBuffer() to use the buffer.
+	// Just give it a big buf and hope the buf will be reused in most scenes.
+	if l > 4095 {
+		buf = GetBuf(l + 1)
+	} else {
+		buf = GetBuf(4096)
+	}
+
+	wire, err = m.PackBuffer(buf.Bytes())
 	if err != nil {
-		allocator.Release(buf)
+		buf.Release()
 		return nil, nil, err
 	}
 	return wire, buf, nil
